@@ -75,7 +75,7 @@ CegoAdmAction::CegoAdmAction(CegoAdminHandler *pAH, CegoModule *pModule, CegoAdm
     // default query cache param values
     _maxEntry = 0;
     _maxSize = 0;
-    _threshold = -1;
+    _threshold = 0;
     _hashRange = 0;
     _cacheFilter = Chain();
 
@@ -126,10 +126,9 @@ void CegoAdmAction::setCommandChain(char *pC)
     _buMsg = Chain("NONE");
     _syncCmd = Chain();
     _timeout = DEFTIMEOUT;
-
     _maxEntry = 0;
     _maxSize = 0;
-    _threshold = -1;
+    _threshold = 0;
     _hashRange = 0;
     _cacheFilter = Chain();
 }
