@@ -257,7 +257,7 @@ private:
     
     char *_pC;
 
-    int _stringBufLen;
+    unsigned _stringBufLen;
     char *_stringBuf; // [MAXSTRINGLEN];
 
     CegoModule *_pModule;
@@ -267,14 +267,14 @@ private:
     Chain _primary;
     Chain _secondary;
 
-    int _sysSize;
-    int _tmpSize;
-    int _appSize;
+    unsigned _sysSize;
+    unsigned _tmpSize;
+    unsigned _appSize;
 
-    int _logSize;
-    int _logNum;
+    unsigned _logSize;
+    unsigned _logNum;
     unsigned long long _sortAreaSize;
-    int _branchId;
+    unsigned _branchId;
     Chain _pit;
 
     bool _rawMode;
@@ -282,7 +282,7 @@ private:
 
     Chain _syncCmd;
     bool _keepTicket;
-    int _timeout;
+    unsigned _timeout;
 
     bool _doCleanup;
     bool _doForceload;
@@ -298,10 +298,10 @@ private:
     Chain _rightPerm;
 
     // query and table cache params
-    int _maxEntry;
-    int _maxSize;
-    int _threshold;
-    int _hashRange;
+    unsigned _maxEntry;
+    unsigned _maxSize;
+    unsigned _threshold;
+    unsigned _hashRange;
     Chain _cacheFilter;
     
     unsigned long _modId;
