@@ -42,15 +42,15 @@ public:
     
     void add(const CegoAttrComp& attrComp);
 
-    int numComp() const;
-    int getStrength() const;
+    unsigned numComp() const;
+    unsigned getStrength() const;
 
     const TreeT<CegoAttrComp>& getAttrCompSet() const;
 
     bool setup(const ListT<CegoField>& fl);
-    bool setup(ListT<CegoField>** pJoinBuf, int offset);
+    bool setup(ListT<CegoField>** pJoinBuf, unsigned offset);
 
-    bool setup(ListT<CegoField>** pParentJoinBuf, int parentOffset, ListT<CegoField>** pJoinBuf, int offset);
+    bool setup(ListT<CegoField>** pParentJoinBuf, unsigned parentOffset, ListT<CegoField>** pJoinBuf, unsigned offset);
     
     CegoAttrCond getFilterCond(const ListT<CegoField>& fl, bool ignoreNullComp) const;    
     CegoAttrCond getIndexCond(const ListT<CegoField>& fl) const;
