@@ -144,7 +144,7 @@ int main(int argc, char **argv)
 	Chain mode = longOpt.getOptValue("mode");
 	Chain logFile = longOpt.getOptValue("logfile");
 	Chain serverName = longOpt.getOptValue("server");
-	int dataPort = longOpt.getOptValue("port").asInteger();
+	unsigned dataPort = longOpt.getOptValue("port").asUnsigned();
 
 	Chain insertSet = longOpt.getOptValue("iset");
 
@@ -181,7 +181,7 @@ int main(int argc, char **argv)
 	Chain tableSet = longOpt.getOptValue("tableset");
 
 	unsigned long long count = longOpt.getOptValue("count").asUnsignedLongLong();
-	int interval = longOpt.getOptValue("interval").asInteger();
+	unsigned interval = longOpt.getOptValue("interval").asUnsigned();
 
 	Operation op = NONE_OP;    
 	if ( mode == Chain("insert") )
@@ -299,7 +299,7 @@ int main(int argc, char **argv)
 		actOp = BLOB_OP;
 	    else if ( op == ARB1_OP )
 	    {
-		int m = random() % 2;
+		unsigned m = random() % 2;
 		if ( m == 0 )
 		    actOp = INSERT_OP;
 		else
@@ -307,7 +307,7 @@ int main(int argc, char **argv)
 	    }
 	    else if ( op == ARB2_OP )
 	    {
-		int m = random() % 3;		
+		unsigned m = random() % 3;		
 		if ( m == 0 )
 		    actOp = INSERT_OP;
 		else if ( m == 1 )
@@ -317,7 +317,7 @@ int main(int argc, char **argv)
 	    }
 	    else if ( op == ARB3_OP )
 	    {
-		int m = random() % 4;
+		unsigned m = random() % 4;
 		if ( m == 0 )
 		    actOp = INSERT_OP;
 		else if ( m == 1 )
@@ -346,7 +346,7 @@ int main(int argc, char **argv)
 			Chain s, len; 
 			tok.nextToken(s); 
 			tok.nextToken(len); 
-			int l = len.asInteger();
+			unsigned l = len.asUnsigned();
 			cmd += Chain(random() % l); 
 		    } 
 		    else if ( col[0] == 's' )
@@ -355,12 +355,12 @@ int main(int argc, char **argv)
 			Chain s, len; 
 			tok.nextToken(s); 
 			tok.nextToken(len); 
-			int l = random() % len.asInteger();
+			unsigned l = random() % len.asUnsigned();
 			if ( l == 0 )
-			    l = len.asInteger();
+			    l = len.asUnsigned();
 			
 			cmd += Chain("'"); 
-			for ( int j=0; j<l; j++ ) 
+			for ( unsigned j=0; j<l; j++ ) 
 			{ 
 			    cmd += Chain((char)(65 + (random()%26))); 
 			} 
@@ -446,17 +446,17 @@ int main(int argc, char **argv)
 		    
 		    if ( type[0] == 'i' )
 		    { 
-			int l = arg.asInteger();
+			unsigned l = arg.asUnsigned();
 			cmd += Chain(random() % l);
 		    }
 		    else if ( type[0] == 's' )
 		    {
-			int l = random() % arg.asInteger();
+			unsigned l = random() % arg.asUnsigned();
 			if ( l == 0 )
-			    l = arg.asInteger();
+			    l = arg.asUnsigned();
 			
 			cmd += Chain("'"); 
-			for ( int j=0; j<l; j++ ) 
+			for ( unsigned j=0; j<l; j++ ) 
 			{ 
 			    cmd += Chain((char)(65 + (random()%26))); 
 			} 
@@ -491,7 +491,7 @@ int main(int argc, char **argv)
 			Chain s, len; 
 			tok.nextToken(s); 
 			tok.nextToken(len); 
-			int l = len.asInteger();
+			unsigned l = len.asUnsigned();
 			cmd += Chain(random() % l); 
 		    } 
 		    else if ( col[0] == 's' ) 
@@ -500,12 +500,12 @@ int main(int argc, char **argv)
 			Chain s, len; 
 			tok.nextToken(s); 
 			tok.nextToken(len); 
-			int l = random() % len.asInteger();
+			unsigned l = random() % len.asUnsigned();
 			if ( l == 0 )
-			    l = len.asInteger();
+			    l = len.asUnsigned();
 			
 			cmd += Chain("'"); 
-			for ( int j=0; j<l; j++ ) 
+			for ( unsigned j=0; j<l; j++ ) 
 			{ 
 			    cmd += Chain((char)(65 + (random()%26))); 
 			} 
@@ -553,17 +553,17 @@ int main(int argc, char **argv)
 		    
 		    if ( utype[0] == 'i' )
 		    { 
-			int l = ulen.asInteger();
+			unsigned l = ulen.asUnsigned();
 			cmd += Chain(random() % l);
 		    }
 		    else if ( utype[0] == 's' )
 		    {
-			int l = random() % ulen.asInteger();
+			unsigned l = random() % ulen.asUnsigned();
 			if ( l == 0 )
-			    l = ulen.asInteger();
+			    l = ulen.asUnsigned();
 			
 			cmd += Chain("'"); 
-			for ( int j=0; j<l; j++ ) 
+			for ( unsigned j=0; j<l; j++ ) 
 			{ 
 			    cmd += Chain((char)(65 + (random()%26))); 
 			} 
@@ -597,17 +597,17 @@ int main(int argc, char **argv)
 		    
 		    if ( wtype[0] == 'i' )
 		    { 
-			int l = warg.asInteger();
+			unsigned l = warg.asUnsigned();
 			cmd += Chain(random() % l);
 		    }
 		    else if ( wtype[0] == 's' )
 		    {
-			int l = random() % warg.asInteger();
+			unsigned l = random() % warg.asUnsigned();
 			if ( l == 0 )
-			    l = warg.asInteger();
+			    l = warg.asUnsigned();
 			
 			cmd += Chain("'"); 
-			for ( int j=0; j<l; j++ ) 
+			for ( unsigned j=0; j<l; j++ ) 
 			{ 
 			    cmd += Chain((char)(65 + (random()%26))); 
 			} 
