@@ -307,9 +307,9 @@ void CegoDistCursor::checkType()
 #endif
 	    _isLocal = false;
 
-	    int tabSetId = oe.getTabSetId();
+	    unsigned tabSetId = oe.getTabSetId();
 	    Chain hostName = _pDBMng->getPrimary(tabSetId);
-	    int portNo;
+	    unsigned portNo;
 	    _pDBMng->getDataPort(portNo);
 
 	    _schema = oe.getSchema();
@@ -643,7 +643,7 @@ void CegoDistCursor::distSetup( CegoAttrCond& attrCond, ListT<CegoField>** pFLA,
     }
 }
 
-bool CegoDistCursor::nextTuple(ListT<CegoField>** pFLA, int pos, int size)
+bool CegoDistCursor::nextTuple(ListT<CegoField>** pFLA, unsigned pos, unsigned size)
 {
     if ( _pGTM->isAborted() )
     {
@@ -702,7 +702,7 @@ bool CegoDistCursor::nextTuple(ListT<CegoField>** pFLA, int pos, int size)
     return false;
 }
 
-bool CegoDistCursor::evalCondition(ListT<CegoField>** pFLA, int pos, int size)
+bool CegoDistCursor::evalCondition(ListT<CegoField>** pFLA, unsigned pos, unsigned size)
 {
     
     if ( _cursorCond.numComp() == 0 )
@@ -737,7 +737,7 @@ bool CegoDistCursor::evalCondition(ListT<CegoField>** pFLA, int pos, int size)
     return validFound;
 }
 
-bool CegoDistCursor::evalCompare(CegoAttrComp *pAC, ListT<CegoField>** pFLA, int pos, int size)
+bool CegoDistCursor::evalCompare(CegoAttrComp *pAC, ListT<CegoField>** pFLA, unsigned pos, unsigned size)
 {
 
     // cout << "Eval compare " << *pAC << endl;	
@@ -745,7 +745,7 @@ bool CegoDistCursor::evalCompare(CegoAttrComp *pAC, ListT<CegoField>** pFLA, int
     
     CegoField *pF = 0;
     
-    int i=0;
+    unsigned i=0;
     while ( pF == 0 && i < size)
     {
 	if ( _pCO->getType() == CegoObject::VIEW || _pCO->getType() == CegoObject::TABLE )
@@ -841,7 +841,7 @@ bool CegoDistCursor::evalCompare(CegoAttrComp *pAC, ListT<CegoField>** pFLA, int
 }
     
 
-bool CegoDistCursor::getTuple(ListT<CegoField>** pFLA, int offset, int size)
+bool CegoDistCursor::getTuple(ListT<CegoField>** pFLA, unsigned offset, unsigned size)
 {
     if ( _pCO->getType() == CegoObject::VIEW )
     {
@@ -945,7 +945,7 @@ bool CegoDistCursor::getTuple(ListT<CegoField>** pFLA, int offset, int size)
 			{
 			    CegoField *pSF = _cacheSchema.First();
 			    
-			    int pos = 0;
+			    unsigned pos = 0;
 			    while ( pF && pSF && ( *pF != *pSF ) )
 			    {				
 				pSF = _cacheSchema.Next();
@@ -1078,7 +1078,7 @@ bool CegoDistCursor::getTuple(ListT<CegoField>** pFLA, int offset, int size)
 	{
 	    CegoDataPointer dp;
 
-	    int len;
+	    unsigned len;
 	    char *pc;
 	    if ( _isFirst )
 	    {
@@ -1096,10 +1096,10 @@ bool CegoDistCursor::getTuple(ListT<CegoField>** pFLA, int offset, int size)
 		unsigned long long tastep;
 		CegoTupleState ts;
 
-		int toff = CegoQueryHelper::decodeTupleHeader(tid, tastep, ts, pc);
+		unsigned toff = CegoQueryHelper::decodeTupleHeader(tid, tastep, ts, pc);
 
 		char* tp = pc + toff;
-		int tlen = len - toff;
+		unsigned tlen = len - toff;
 
 		CegoQueryHelper::decodeFVL(*pFLA[offset], tp, tlen);
 		
@@ -1135,7 +1135,7 @@ bool CegoDistCursor::getTuple(ListT<CegoField>** pFLA, int offset, int size)
 		     || _tableName == Chain(SYSTAB_INDEX_ID)
 		     || _tableName == Chain(SYSTAB_BTREE_ID) )
 		{	    
-		    int pageCount = 0;
+		    unsigned pageCount = 0;
 		    
 		    if ( _tableName == Chain(SYSTAB_TABLE_ID)  )
 			pageCount = _pGTM->getPageCount(_tabSetId, *pName, CegoObject::TABLE);
@@ -1466,7 +1466,7 @@ bool CegoDistCursor::getTuple(ListT<CegoField>** pFLA, int offset, int size)
 	    {
 		if ( _moreLeft == false )
 		{
-		    for ( int i=0; i<size-1; i++)
+		    for ( unsigned i=0; i<size-1; i++)
 		    {
 			// make right fields null
 			CegoField *pF = pFLA[offset+i]->First();
@@ -1488,7 +1488,7 @@ bool CegoDistCursor::getTuple(ListT<CegoField>** pFLA, int offset, int size)
     throw Exception(EXLOC, msg);
 }
 
-void CegoDistCursor::nextRight(ListT<CegoField>** pFLA, int offset, int size)
+void CegoDistCursor::nextRight(ListT<CegoField>** pFLA, unsigned offset, unsigned size)
 {
     CegoJoinObject *pJO = (CegoJoinObject*)_pCO;
 	
@@ -1534,7 +1534,7 @@ void CegoDistCursor::nextRight(ListT<CegoField>** pFLA, int offset, int size)
     }
 }
 
-void CegoDistCursor::nextLeft(ListT<CegoField>** pFLA, int offset, int size)
+void CegoDistCursor::nextLeft(ListT<CegoField>** pFLA, unsigned offset, unsigned size)
 {
     CegoJoinObject *pJO = (CegoJoinObject*)_pCO;
     
