@@ -26,13 +26,13 @@
 #include "CegoBufferPage.h"
 
 #define BIT_PER_BYTE 8
-#define FILEHEADSIZE sizeof(int) + sizeof(FileType) + sizeof(int) + sizeof(PageIdType)
+#define FILEHEADSIZE sizeof(unsigned) + sizeof(FileType) + sizeof(unsigned) + sizeof(PageIdType)
 
 extern bool __fsyncOn;
 
 CegoFileHandler::CegoFileHandler(const Chain& logFile, const Chain& progName) : CegoModule(logFile, progName)
 {
-    for (int i = 0; i<FILMNG_MAXDATAFILE; i++)
+    for (unsigned i = 0; i<FILMNG_MAXDATAFILE; i++)
     {
 	_isReg[i]=false;
 	_tabSetId[i]=0;
@@ -49,7 +49,7 @@ CegoFileHandler::CegoFileHandler(const Chain& logFile, const Chain& progName) :
 
 CegoFileHandler::~CegoFileHandler()
 {
-    for (int i = 0; i<FILMNG_MAXDATAFILE; i++)
+    for (unsigned i = 0; i<FILMNG_MAXDATAFILE; i++)
     {
 	if ( _fhList[i] != 0 )
 	{
@@ -72,7 +72,7 @@ void CegoFileHandler::setReadOnly(bool isReadOnly)
     _isReadOnly = isReadOnly;
 }
 
-void CegoFileHandler::setBackup(int fileId, bool m)
+void CegoFileHandler::setBackup(unsigned fileId, bool m)
 {
     if ( m == true )
     {
@@ -98,7 +98,7 @@ void CegoFileHandler::setBackup(int fileId, bool m)
 
 bool CegoFileHandler::needPageBackup(PageIdType pageId)
 {
-    int fileId = getFileIdForPageId(pageId);
+    unsigned fileId = getFileIdForPageId(pageId);
 
     // check if backup is activated for file
     if ( _buMask[fileId] )
@@ -114,7 +114,7 @@ bool CegoFileHandler::needPageBackup(PageIdType pageId)
 
 void CegoFileHandler::markPage(PageIdType pageId)
 {
-    int fileId = getFileIdForPageId(pageId);
+    unsigned fileId = getFileIdForPageId(pageId);
     
     if ( _buMask[fileId] == 0 )
     {
@@ -133,7 +133,7 @@ void CegoFileHandler::markPage(PageIdType pageId)
     _buMask[fileId][bmid] = bm | f;
 }
 
-bool CegoFileHandler::isPageMarked(PageIdType pageId, int fileId)
+bool CegoFileHandler::isPageMarked(PageIdType pageId, unsigned fileId)
 {
     if ( _buMask[fileId] == 0 )
     {
@@ -155,7 +155,7 @@ bool CegoFileHandler::isPageMarked(PageIdType pageId, int fileId)
     return false;
 }
 
-PageIdType CegoFileHandler::getPageOffset(int fileId)
+PageIdType CegoFileHandler::getPageOffset(unsigned fileId)
 {
     return _pageOffset[fileId];
 }
@@ -165,7 +165,7 @@ PageIdType CegoFileHandler::getMaxPageOffset()
 {
     PageIdType maxOffset=1;
     
-    for (int i = 0; i<FILMNG_MAXDATAFILE; i++)
+    for (unsigned i = 0; i<FILMNG_MAXDATAFILE; i++)
     {
 	if (  _pageOffset[i] + _numPages[i] > maxOffset )
 	    maxOffset = _pageOffset[i] + _numPages[i];
@@ -173,12 +173,12 @@ PageIdType CegoFileHandler::getMaxPageOffset()
     return maxOffset;
 }
 
-int CegoFileHandler::getFBMSize(int fileId)
+unsigned CegoFileHandler::getFBMSize(unsigned fileId)
 {
     return (_numPages[fileId] / (BIT_PER_BYTE * sizeof(unsigned))) + 1;
 }
 
-void CegoFileHandler::readFBM(int fileId, unsigned *fbm, CegoLockHandler *pLockHandle)
+void CegoFileHandler::readFBM(unsigned fileId, unsigned *fbm, CegoLockHandler *pLockHandle)
 {
     File *pF;
 
@@ -197,8 +197,8 @@ void CegoFileHandler::readFBM(int fileId, unsigned *fbm, CegoLockHandler *pLockH
     {
 	pF->seek(FILEHEADSIZE);
 
-	int numBitmap = (_numPages[fileId] / (BIT_PER_BYTE * sizeof(unsigned))) + 1;
-	int i;
+	unsigned numBitmap = (_numPages[fileId] / (BIT_PER_BYTE * sizeof(unsigned))) + 1;
+	unsigned i;
 	for (i = 0; i < numBitmap; i++)
 	{
 	    pF->readByte((char*)&fbm[i], sizeof(unsigned));
@@ -213,7 +213,7 @@ void CegoFileHandler::readFBM(int fileId, unsigned *fbm, CegoLockHandler *pLockH
     }
 }
 
-void CegoFileHandler::writeFBM(int fileId, unsigned *fbm, CegoLockHandler *pLockHandle)
+void CegoFileHandler::writeFBM(unsigned fileId, unsigned *fbm, CegoLockHandler *pLockHandle)
 {
     if ( _isReadOnly == true )
 	return;
@@ -235,8 +235,8 @@ void CegoFileHandler::writeFBM(int fileId, unsigned *fbm, CegoLockHandler *pLock
     {	
 	pF->seek(FILEHEADSIZE);
 
-	int numBitmap = (_numPages[fileId] / (BIT_PER_BYTE * sizeof(unsigned))) + 1;
-	int i;
+	unsigned numBitmap = (_numPages[fileId] / (BIT_PER_BYTE * sizeof(unsigned))) + 1;
+	unsigned i;
 
 	for (i = 0; i < numBitmap; i++)
 	{
@@ -260,7 +260,7 @@ void CegoFileHandler::writeFBM(int fileId, unsigned *fbm, CegoLockHandler *pLock
    the file is created and initialized. Note, that after creation the datafile is still NOT registered for further usage.
    This must be done using the regDataFile method */
 
-void CegoFileHandler::initDataFile(int tabSetId, const Chain& path, int fileId, int numPages, PageIdType pageOffset, FileType ft)
+void CegoFileHandler::initDataFile(unsigned tabSetId, const Chain& path, unsigned fileId, unsigned numPages, PageIdType pageOffset, FileType ft)
 {
     if ( _isReadOnly == true )
 	return;
@@ -278,16 +278,16 @@ void CegoFileHandler::initDataFile(int tabSetId, const Chain& path, int fileId,
     {
 	pF->open(File::WRITE);
 	
-	pF->writeByte((char*)&tabSetId, sizeof(int));
+	pF->writeByte((char*)&tabSetId, sizeof(unsigned));
 	pF->writeByte((char*)&ft, sizeof(FileType));
 	// cout << "Init datafile " << path << " with numPages " << numPages << endl;
-	pF->writeByte((char*)&numPages, sizeof(int));
+	pF->writeByte((char*)&numPages, sizeof(unsigned));
 	
 	pF->writeByte((char*)&pageOffset, sizeof(PageIdType));
 		
-	int i;
+	unsigned i;
 	
-	for (i = 0; i < (int)((numPages / (BIT_PER_BYTE * sizeof(unsigned))) + 1); i++)
+	for (i = 0; i < (unsigned)((numPages / (BIT_PER_BYTE * sizeof(unsigned))) + 1); i++)
 	{
 	    unsigned bm = 0;
 	    pF->writeByte((char*)&bm, sizeof(unsigned));
@@ -315,7 +315,7 @@ void CegoFileHandler::initDataFile(int tabSetId, const Chain& path, int fileId,
     }
 }
 
-void CegoFileHandler::resetDataFile(int fileId)
+void CegoFileHandler::resetDataFile(unsigned fileId)
 {
     if ( _isReadOnly == true )
 	return;
@@ -333,9 +333,9 @@ void CegoFileHandler::resetDataFile(int fileId)
     
     pF->seek(FILEHEADSIZE);
         
-    int i;
+    unsigned i;
     
-    for (i = 0; i < (int)(( _numPages[fileId] / (BIT_PER_BYTE * sizeof(unsigned)))) + 1; i++)
+    for (i = 0; i < (unsigned)(( _numPages[fileId] / (BIT_PER_BYTE * sizeof(unsigned)))) + 1; i++)
     {
 	unsigned bm = 0;
 	pF->writeByte((char*)&bm, sizeof(unsigned));
@@ -348,7 +348,7 @@ void CegoFileHandler::resetDataFile(int fileId)
 /* the regDataFile method is used for datafile registration. The given file is checked
    for consistency and is registered */
 
-void CegoFileHandler::regDataFile(int tabSetId, const Chain& path, int fileId, CegoLockHandler *pLockHandle)
+void CegoFileHandler::regDataFile(unsigned tabSetId, const Chain& path, unsigned fileId, CegoLockHandler *pLockHandle)
 {
     pLockHandle->lockDataFile(fileId, CegoLockHandler::READ);
 
@@ -368,8 +368,8 @@ void CegoFileHandler::regDataFile(int tabSetId, const Chain& path, int fileId, C
 	}
     }
 
-    int checkTabSetId;
-    int numPage;
+    unsigned checkTabSetId;
+    unsigned numPage;
     PageIdType pageOffset;
     
     FileType ft;
@@ -379,9 +379,9 @@ void CegoFileHandler::regDataFile(int tabSetId, const Chain& path, int fileId, C
 	File checkFile(path);	    
 	checkFile.open(File::READ);
 	
-	checkFile.readByte((char*)&checkTabSetId, sizeof(int));	
+	checkFile.readByte((char*)&checkTabSetId, sizeof(unsigned));	
 	checkFile.readByte((char*)&ft, sizeof(FileType));
-	checkFile.readByte((char*)&numPage, sizeof(int));
+	checkFile.readByte((char*)&numPage, sizeof(unsigned));
 	checkFile.readByte((char*)&pageOffset, sizeof(PageIdType));
 
 	checkFile.close();	
@@ -414,9 +414,9 @@ void CegoFileHandler::regDataFile(int tabSetId, const Chain& path, int fileId, C
 /* all registered files of the corresponding table set are closed and unregistered 
    with the releaseFiles method */
 
-void CegoFileHandler::releaseFiles(int tabSetId)
+void CegoFileHandler::releaseFiles(unsigned tabSetId)
 {
-    for (int i = 0; i<FILMNG_MAXDATAFILE; i++)
+    for (unsigned i = 0; i<FILMNG_MAXDATAFILE; i++)
     {
 	if ( _tabSetId[i] == tabSetId )
 	{
@@ -442,7 +442,7 @@ void CegoFileHandler::writePage(PageIdType pageId, unsigned fixStat, char* pageD
     if ( _isReadOnly == true )
 	throw Exception(EXLOC, Chain("Cannot write page in read only mode"));
         
-    int fileId = getFileIdForPageId(pageId);
+    unsigned fileId = getFileIdForPageId(pageId);
     
     File* pF;
 
@@ -484,9 +484,9 @@ void CegoFileHandler::writePage(PageIdType pageId, unsigned fixStat, char* pageD
 /* pages from datafiles are read by using the readPage method. The method seeks to the appropriate offset
    in the corresponding datafile and reads the page data into the given data pointer */
 
-void CegoFileHandler::readPage(PageIdType pageId, int& tabSetId, unsigned& fixStat, char* pageData, CegoLockHandler *pLockHandle)
+void CegoFileHandler::readPage(PageIdType pageId, unsigned& tabSetId, unsigned& fixStat, char* pageData, CegoLockHandler *pLockHandle)
 {
-    int fileId = getFileIdForPageId(pageId);
+    unsigned fileId = getFileIdForPageId(pageId);
     
     File *pF;
 
@@ -504,7 +504,7 @@ void CegoFileHandler::readPage(PageIdType pageId, int& tabSetId, unsigned& fixSt
     try 
     {
 	pF->seek(0);
-	pF->readByte((char*)&tabSetId, sizeof(int));
+	pF->readByte((char*)&tabSetId, sizeof(unsigned));
 	
 	unsigned long offset = FILEHEADSIZE 
 	    +  ((_numPages[fileId] / ( BIT_PER_BYTE * sizeof(unsigned) )) + 1) * sizeof(unsigned) ;
@@ -514,7 +514,7 @@ void CegoFileHandler::readPage(PageIdType pageId, int& tabSetId, unsigned& fixSt
 	pF->readByte((char*)&fixStat, sizeof(unsigned));
 	
 	unsigned long rb = pF->readByte(pageData, _pageSize);
-	while ( (int)rb < _pageSize )
+	while ( (unsigned)rb < _pageSize )
 	{	  
 	    unsigned long rrb = pF->readByte((char*)((long long)pageData + rb), _pageSize - rb);
 	       
@@ -542,7 +542,7 @@ void CegoFileHandler::claimPage(PageIdType pageId, CegoLockHandler *pLockHandle)
     if ( _isReadOnly == true )
 	throw Exception(EXLOC, Chain("Cannot claim page in read only mode"));
 
-    int fileId = getFileIdForPageId(pageId);
+    unsigned fileId = getFileIdForPageId(pageId);
 
     File *pF;
 
@@ -604,12 +604,12 @@ void CegoFileHandler::claimPage(PageIdType pageId, CegoLockHandler *pLockHandle)
    the required filetype must be specified. 
    the method returns the assigned file and page information */
 
-void CegoFileHandler::allocatePage(int tabSetId, FileType ft, PageIdType& pageId, CegoLockHandler *pLockHandle, unsigned* &fbm, int& fbmSize, bool doAppend)
+void CegoFileHandler::allocatePage(unsigned tabSetId, FileType ft, PageIdType& pageId, CegoLockHandler *pLockHandle, unsigned* &fbm, unsigned& fbmSize, bool doAppend)
 {    
     if ( _isReadOnly == true )
 	throw Exception(EXLOC, Chain("Cannot allocate page in read only mode"));
 
-    int fid = 0;  
+    unsigned fid = 0;  
     if ( doAppend )
 	fid = _appendFid;
    
@@ -626,7 +626,7 @@ void CegoFileHandler::allocatePage(int tabSetId, FileType ft, PageIdType& pageId
 	    {
 		unsigned ws = sizeof(unsigned)*BIT_PER_BYTE;
 
-		PageIdType k;
+		unsigned k;
 
 		if ( doAppend == false || _appendPos[fid] == 0)
 		{
@@ -644,7 +644,7 @@ void CegoFileHandler::allocatePage(int tabSetId, FileType ft, PageIdType& pageId
 		
 		// cout << "k=" << k << " numPages = " << _numPages[fid] << endl;
 
-		bool isEop = (int)k >= _numPages[fid];
+		bool isEop = k >= _numPages[fid];
 		
 		while (!isEop)
 		{
@@ -663,7 +663,7 @@ void CegoFileHandler::allocatePage(int tabSetId, FileType ft, PageIdType& pageId
 			unsigned l = 0;
 			while (l < ws && ! isEop)
 			{
-			    if ( (int)(k+l) < _numPages[fid])
+			    if ( (k+l) < _numPages[fid])
 			    {
 				unsigned checkbit = bm >> l & ~(~(unsigned)0 << 1);
 				if (checkbit == 0)
@@ -759,12 +759,12 @@ void CegoFileHandler::allocatePage(int tabSetId, FileType ft, PageIdType& pageId
 /* if a page is no longer used, it can be released using the releasePage method.
    Normally this is used, in case of delete operations or in case of temporarily used pages */
 
-void CegoFileHandler::releasePage(PageIdType pageId, CegoLockHandler *pLockHandle, unsigned* &fbm, int& fbmSize)
+void CegoFileHandler::releasePage(PageIdType pageId, CegoLockHandler *pLockHandle, unsigned* &fbm, unsigned& fbmSize)
 {    
     if ( _isReadOnly == true )
 	throw Exception(EXLOC, Chain("Cannot releases page in read only mode"));
 
-    int fileId = getFileIdForPageId(pageId);
+    unsigned fileId = getFileIdForPageId(pageId);
     
     File* pF;
     
@@ -837,15 +837,15 @@ void CegoFileHandler::releasePage(PageIdType pageId, CegoLockHandler *pLockHandl
 
 void CegoFileHandler::commitPageEntry(PageIdType pageId)
 {
-    int fileId = getFileIdForPageId(pageId);
+    unsigned fileId = getFileIdForPageId(pageId);
 
     if ( _commitMask[fileId] == 0 )
     {
     	_commitMask[fileId] = new unsigned[ (  getNumPages(fileId) / (BIT_PER_BYTE * sizeof(unsigned))) + 1];
 
-	int i;
+	unsigned i;
 	
-	for (i = 0; i < (int)(( getNumPages(fileId) / (BIT_PER_BYTE * sizeof(unsigned))) + 1); i++)
+	for (i = 0; i < (unsigned)(( getNumPages(fileId) / (BIT_PER_BYTE * sizeof(unsigned))) + 1); i++)
 	{
 	    _commitMask[fileId][i] = 0;
 	}
@@ -862,25 +862,25 @@ void CegoFileHandler::commitPageEntry(PageIdType pageId)
     _commitMask[fileId][bmid] = bm | f;    
 }
 
-int CegoFileHandler::cleanPages(CegoLockHandler *pLockHandle)
+unsigned CegoFileHandler::cleanPages(CegoLockHandler *pLockHandle)
 {
     if ( _isReadOnly == true )
 	throw Exception(EXLOC, Chain("Cannot clean pages in read only mode"));
 
-    int numCleanup = 0;
+    unsigned numCleanup = 0;
     
-    for (int i = 0; i<FILMNG_MAXDATAFILE; i++)
+    for (unsigned i = 0; i<FILMNG_MAXDATAFILE; i++)
     {
 	if ( _isReg[i] && _fileType[i] == DATAFILE && _commitMask[i])
 	{
 	    
-	    int fbmSize = getFBMSize(i);
+	    unsigned fbmSize = getFBMSize(i);
 	    unsigned* fbm = new unsigned[fbmSize]; 							    
 	    readFBM(i, fbm, pLockHandle);
 
 	    bool cleanupNeeded = false;
 	    
-	    for ( int j=0; j<fbmSize; j++ )
+	    for ( unsigned j=0; j<fbmSize; j++ )
 	    {
 		// cout << "Checking mask " << _commitMask[i][j] << endl;
 		
@@ -914,7 +914,7 @@ int CegoFileHandler::cleanPages(CegoLockHandler *pLockHandle)
 
 /* returns the number of total pages for the given fileId */
 
-int CegoFileHandler::getNumPages(int fileId)
+unsigned CegoFileHandler::getNumPages(unsigned fileId)
 {
     try 
     {
@@ -931,7 +931,7 @@ int CegoFileHandler::getNumPages(int fileId)
 
 /* returns the number of used pages for the given fileId */
 
-int CegoFileHandler::getNumUsedPages(int fileId, CegoLockHandler *pLockHandle)
+unsigned CegoFileHandler::getNumUsedPages(unsigned fileId, CegoLockHandler *pLockHandle)
 {   
     File *pF;
 
@@ -948,31 +948,31 @@ int CegoFileHandler::getNumUsedPages(int fileId, CegoLockHandler *pLockHandle)
 
     try
     {	
-	pF->seek(sizeof(int) + sizeof(FileType));
+	pF->seek(sizeof(unsigned) + sizeof(FileType));
 	
-	int numPage;	
-	pF->readByte((char*)&numPage, sizeof(int));
+	unsigned numPage;	
+	pF->readByte((char*)&numPage, sizeof(unsigned));
 
 	PageIdType pageOffset;
 	pF->readByte((char*)&pageOffset, sizeof(PageIdType));
 		
-	int p;
+	unsigned p;
 	
-	int usedPages = 0;
+	unsigned usedPages = 0;
 
-	for ( p = 0; p < (int)((numPage / (BIT_PER_BYTE * sizeof(unsigned))) + 1); p++ )
+	for ( p = 0; p < (unsigned)((numPage / (BIT_PER_BYTE * sizeof(unsigned))) + 1); p++ )
 	{
 	    unsigned bm = 0;
 	    pF->readByte((char*)&bm, sizeof(unsigned));
 	    
 	    // printBitMap(bm);
 	    
-	    int i,j;
-	    for (i = 0; i< (int)sizeof(unsigned); i++)
+	    unsigned i,j;
+	    for (i = 0; i< (unsigned)sizeof(unsigned); i++)
 	    {
 		for (j=0; j < BIT_PER_BYTE; j++)
 		{
-		    int one = 1;
+		    unsigned one = 1;
 		    
 		    if ( one & bm )
 		    {
@@ -1003,7 +1003,7 @@ int CegoFileHandler::getNumUsedPages(int fileId, CegoLockHandler *pLockHandle)
  
 bool CegoFileHandler::isClaimed(PageIdType pageId, CegoLockHandler *pLockHandle)
 {
-    int fileId = getFileIdForPageId(pageId);
+    unsigned fileId = getFileIdForPageId(pageId);
 	
     File *pF;
 
@@ -1051,9 +1051,9 @@ bool CegoFileHandler::isClaimed(PageIdType pageId, CegoLockHandler *pLockHandle)
     }
 }
 
-int CegoFileHandler::getFileIdForPageId(PageIdType pageId)
+unsigned CegoFileHandler::getFileIdForPageId(PageIdType pageId)
 {
-    int i=0;
+    unsigned i=0;
     
     while ( i < FILMNG_MAXDATAFILE )
     {
@@ -1071,7 +1071,7 @@ int CegoFileHandler::getFileIdForPageId(PageIdType pageId)
    returns the file handle. Otherwise, the corresponding file is opened
    for reading and writing and the handle is returned. */
 
-File* CegoFileHandler::getHandle(int fileId)
+File* CegoFileHandler::getHandle(unsigned fileId)
 {
     if ( fileId > FILMNG_MAXDATAFILE - 1 ) 
     {
@@ -1119,7 +1119,7 @@ void CegoFileHandler::printBitMap(unsigned bm)
 {    
     printf("--- BM -----------\n");
     
-    int i,j;
+    unsigned i,j;
     for (i = 0; i< (int)sizeof(unsigned); i++)
     {
 	for (j=0; j < BIT_PER_BYTE; j++)
@@ -1139,12 +1139,12 @@ void CegoFileHandler::printBitMap(unsigned bm)
     printf("--------------\n");    
 }
 
-int CegoFileHandler::mapDiff(unsigned bm1, unsigned bm2)
+unsigned CegoFileHandler::mapDiff(unsigned bm1, unsigned bm2)
 {    
-    int numDiff = 0;
+    unsigned numDiff = 0;
     
-    int i,j;
-    for (i = 0; i< (int)sizeof(unsigned); i++)
+    unsigned i,j;
+    for (i = 0; i< (unsigned)sizeof(unsigned); i++)
     {
 	for (j=0; j < BIT_PER_BYTE; j++)
 	{
