@@ -283,7 +283,7 @@ void CegoJDBCInfo::handleRequest(const ListT<Chain>& argList) const
 		ListT<CegoCheckObject> checkList;
 		ListT<CegoTriggerObject> triggerList;
 		ListT<CegoAliasObject> aliasList;
-		int numInvalid;
+		unsigned numInvalid;
 
 		_pTabMng->getDistObjectByTableList(*pTS, *pTable, idxList, btreeList, keyList, checkList, triggerList, aliasList, numInvalid);
 		
@@ -309,7 +309,7 @@ void CegoJDBCInfo::handleRequest(const ListT<Chain>& argList) const
 			CegoTableObject oe;
 			_pTabMng->getDistObject(*pTS, pIdx->getName(), CegoObject::AVLTREE, oe);
 			
-			int i=1;
+			unsigned i=1;
 			CegoField *pF = oe.getSchema().First();
 			while ( pF )
 			{
@@ -337,7 +337,7 @@ void CegoJDBCInfo::handleRequest(const ListT<Chain>& argList) const
 			    CegoBTreeObject oe;
 			    _pTabMng->getDistObject(*pTS, pBTree->getName(), CegoObject::BTREE, oe);
 			    
-			    int i=1;
+			    unsigned i=1;
 			    CegoField *pF = oe.getSchema().First();
 			    while ( pF )
 			    {
@@ -380,7 +380,7 @@ void CegoJDBCInfo::handleRequest(const ListT<Chain>& argList) const
 		ListT<CegoCheckObject> checkList;
 		ListT<CegoTriggerObject> triggerList;
 		ListT<CegoAliasObject> aliasList;
-		int numInvalid;
+		unsigned numInvalid;
 
 		_pTabMng->getDistObjectByTableList(*pTS, *pTable, idxList, btreeList, keyList, checkList, triggerList, aliasList, numInvalid);
 
@@ -414,7 +414,7 @@ void CegoJDBCInfo::handleRequest(const ListT<Chain>& argList) const
 			CegoKeyObject ko;
 			_pTabMng->getDistObject(*pTS, pKey->getName(), CegoObject::FKEY, ko);
 			
-			int i=1;
+			unsigned i=1;
 			CegoField *pKF = ko.getKeySchema().First();
 			CegoField *pRF = ko.getRefSchema().First();
 			while ( pKF && pRF)
@@ -466,7 +466,7 @@ void CegoJDBCInfo::handleRequest(const ListT<Chain>& argList) const
 		ListT<CegoCheckObject> checkList;
 		ListT<CegoTriggerObject> triggerList;
 		ListT<CegoAliasObject> aliasList;
-		int numInvalid;
+		unsigned numInvalid;
 
 		_pTabMng->getDistObjectByTableList(*pTS, *pTable, idxList, btreeList, keyList, checkList, triggerList, aliasList, numInvalid);
 
@@ -501,7 +501,7 @@ void CegoJDBCInfo::handleRequest(const ListT<Chain>& argList) const
 			CegoKeyObject ko;
 			_pTabMng->getDistObject(*pTS, pKey->getName(), CegoObject::FKEY, ko);
 			
-			int i=1;
+			unsigned i=1;
 			CegoField *pKF = ko.getKeySchema().First();
 			CegoField *pRF = ko.getRefSchema().First();
 			while ( pKF && pRF)
@@ -554,7 +554,7 @@ void CegoJDBCInfo::handleRequest(const ListT<Chain>& argList) const
 		ListT<CegoCheckObject> checkList;
 		ListT<CegoTriggerObject> triggerList;
 		ListT<CegoAliasObject> aliasList;
-		int numInvalid;
+		unsigned numInvalid;
 
 		_pTabMng->getDistObjectByTableList(*pTS, *pTable, idxList, btreeList, keyList, checkList, triggerList, aliasList, numInvalid);
 
@@ -586,7 +586,7 @@ void CegoJDBCInfo::handleRequest(const ListT<Chain>& argList) const
 		    CegoTableObject io;
 		    _pTabMng->getDistObject(*pTS, pIdx->getName(), CegoObject::AVLTREE, io);
 		    
-		    int i=1;
+		    unsigned i=1;
 		    CegoField *pIF = io.getSchema().First();
 		    while ( pIF)
 		    {
@@ -624,7 +624,7 @@ void CegoJDBCInfo::handleRequest(const ListT<Chain>& argList) const
 		    CegoBTreeObject bto;
 		    _pTabMng->getDistObject(*pTS, pBTree->getName(), CegoObject::BTREE, bto);
 		    
-		    int i=1;
+		    unsigned i=1;
 		    CegoField *pIF = bto.getSchema().First();
 		    while ( pIF)
 		    {
@@ -714,7 +714,7 @@ void CegoJDBCInfo::handleRequest(const ListT<Chain>& argList) const
 		
 		o.headOut();
 		
-		int i=1;
+		unsigned i=1;
 		CegoField *pF = oe.getSchema().First();
 		while ( pF )
 		{
