@@ -53,13 +53,13 @@ public:
     ~CegoRecoveryManager();
 
     unsigned long long recoverTableSet(const Chain& tableSet, long long pit, CegoAdminHandler* pAH);
-    RecoveryState recoverCurrentTransactionLog(int tabSetId, long long pit, unsigned long long& lsn, long long& ts);
+    RecoveryState recoverCurrentTransactionLog(unsigned tabSetId, long long pit, unsigned long long& lsn, long long& ts);
     
 private:
 
-    unsigned long long dataFileRecovery(const Chain& tableSet, int tabSetId, unsigned long long  lsn, CegoAdminHandler* pAH);
-    unsigned long long transactionRecovery(const Chain& tableSet, int tabSetId, unsigned long long cplsn, long long pit, CegoAdminHandler* pAH);
-    int recoverCurrentDataFileLog(int tabSetId, bool& endOfBackup);
+    unsigned long long dataFileRecovery(const Chain& tableSet, unsigned tabSetId, unsigned long long  lsn, CegoAdminHandler* pAH);
+    unsigned long long transactionRecovery(const Chain& tableSet, unsigned tabSetId, unsigned long long cplsn, long long pit, CegoAdminHandler* pAH);
+    unsigned long long recoverCurrentDataFileLog(unsigned tabSetId, bool& endOfBackup);
     bool restoreLogFile(const Chain& tableSet, unsigned long lsn);
     
     Logger* _pLogger;
