@@ -40,7 +40,7 @@ public:
     
     const Chain& getVarName() const;
     CegoExpr* getExpr() const;
-    Chain toChain(int defTabSetId) const;    
+    Chain toChain(unsigned defTabSetId) const;    
     Chain dbFormat(CegoDatabaseFormater *pForm) const;
 
     CegoReturnVar& operator = ( const CegoReturnVar& rv);
