@@ -1966,11 +1966,16 @@ bool CegoSelect::nextJoinTuple(ListT<CegoField>& jfl, ListT<CegoField>& ofl)
 			    }
 			    i++;
 			}
+			/* there might be attributes in nested selects or parent queries, which cannot be found
+			   so this check is not useful */
+
+			/*
 			if ( notFound )
 			{
 			    Chain msg = Chain("Unknown order attribute ") + (*pAttrRef)->getTableName() + Chain(".") + (*pAttrRef)->getAttrName();
 			    throw Exception(EXLOC, msg);
-			}			
+			}
+			*/
 			pAttrRef = attrRefList.Next();
 		    }
 		    
